==> vpp-0.7.1.zip: html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "VPP", "index.html", [
    [ "System classes", "index.html#sysClasses", null ],
    [ "Render and compute pass construction classes", "index.html#renderPassConstruction", null ],
    [ "Resource objects", "index.html#resObjects", null ],
    [ "Memory allocation", "index.html#memAlloc", null ],
    [ "Data containers", "index.html#dataContainers", null ],
    [ "Pipeline construction classes", "index.html#pipelineConstruction", null ],
    [ "High level execution", "index.html#cmdExecHi", null ],
    [ "Recording and execution of commands", "index.html#cmdExecLo", null ],
    [ "Synchronization primitives", "index.html#syncPrimitives", null ],
    [ "Rendering configuration classes", "index.html#renderOptions", null ],
    [ "Resource binding points", "index.html#bindPoints", [
      [ "Vertex and instance data", "index.html#bpVertex", null ],
      [ "Uniform, storage and texel data buffers", "index.html#vpUniform", null ],
      [ "Push constants", "index.html#bpPushcon", null ],
      [ "Images and textures", "index.html#bpImg", null ],
      [ "Arrays of resource binding points", "index.html#bpArr", null ],
      [ "Render graph attachments", "index.html#bpAttach", null ],
      [ "Inter-shader communication", "index.html#bpIO", null ]
    ] ],
    [ "Binding point accessors", "index.html#bpAccessors", null ],
    [ "Resource views", "index.html#resViews", null ],
    [ "Resource binding helpers", "index.html#resBindHelpers", null ],
    [ "Shader binding points", "index.html#shBindPoints", null ],
    [ "Shader interface classes", "index.html#shInterfaces", null ],
    [ "Shader language simple data types", "index.html#shSimpleTypes", null ],
    [ "Shader language compound data types", "index.html#shCompoundTypes", null ],
    [ "Shader language constructs", "index.html#shLangConstructs", null ],
    [ "Shader language functions", "index.html#shLangFunctions", null ],
    [ "Shader language functions for accessing textures and images", "index.html#shLangImgFunctions", null ],
    [ "Debugging helpers", "index.html#dbgHelpers", null ],
    [ "How to build and use VPP under Visual Studio", "page_build_v_s.html", [
      [ "How to build and use VPP under Visual Studio", "page_build_v_s.html#secBuildVS", [
        [ "Build properties", "page_build_v_s.html#secBuildProps", null ],
        [ "Configurations and platforms", "page_build_v_s.html#secConfigs", null ],
        [ "Project file", "page_build_v_s.html#secProject", null ]
      ] ]
    ] ],
    [ "General overview of rendering with VPP", "page_general_overview.html", null ],
    [ "How do C++ shaders work", "page_shaders_explanation.html", null ],
    [ "How do render graphs work", "page_render_graphs.html", [
      [ "How do render graphs work", "page_render_graphs.html#secHowDoRenderGraphs", [
        [ "Render graph basics", "page_render_graphs.html#secRenderGraphBasics", null ],
        [ "Render pass basics", "page_render_graphs.html#secRenderPassBasics", null ],
        [ "Advanced topics", "page_render_graphs.html#secAdvanced", null ]
      ] ]
    ] ],
    [ "How do pipelines work", "page_pipelines.html", [
      [ "How do pipelines work", "page_pipelines.html#secHowDoPipelines", [
        [ "Defining custom pipelines - pipeline configurations", "page_pipelines.html#secPipelineConfigs", null ],
        [ "Compiled form - pipeline layouts", "page_pipelines.html#secPipelineLayouts", null ],
        [ "Fully realized form - pipelines", "page_pipelines.html#secPipelines", null ]
      ] ]
    ] ],
    [ "Methods of supplying data", "page_supply_data.html", [
      [ "Buffers", "page_supply_data.html#secBuffers", [
        [ "Basic buffer classes in VPP", "page_supply_data.html#secBufferClasses", null ],
        [ "Buffer types and usages", "page_supply_data.html#secBufferUsages", null ],
        [ "Memory allocation", "page_supply_data.html#secBufferMemory", null ],
        [ "Vectors", "page_supply_data.html#secBufferVectors", null ],
        [ "Buffer views", "page_supply_data.html#secBufferViews", null ],
        [ "Buffer binding points", "page_supply_data.html#secBufferBindingPoints", null ],
        [ "Shader data blocks", "page_supply_data.html#secShaderDataBlocks", null ],
        [ "Binding buffers to points", "page_supply_data.html#secBufferBindingUpdates", null ],
        [ "Binding vertex buffers to pipelines", "page_supply_data.html#secBufferBindingVertex", null ],
        [ "Defining the structure for vertex buffers", "page_supply_data.html#secBufferDefiningVertex", null ],
        [ "Defining the structure for instance buffers", "page_supply_data.html#secBufferDefiningInstance", null ],
        [ "Defining the structure for uniform buffers", "page_supply_data.html#secBufferDefiningUniform", null ]
      ] ],
      [ "Images", "page_supply_data.html#secImages", [
        [ "Basic image classes in VPP", "page_supply_data.html#secImageClasses", null ],
        [ "Images with dynamic format", "page_supply_data.html#secImageDynFormat", null ],
        [ "Image types and usages", "page_supply_data.html#secImageUsages", null ],
        [ "Memory allocation", "page_supply_data.html#secImageMemory", null ],
        [ "Samplers", "page_supply_data.html#secImageSamplers", null ],
        [ "Image views", "page_supply_data.html#secImageViews", null ],
        [ "Image binding points", "page_supply_data.html#secImageBindingPoints", null ],
        [ "Binding images to points", "page_supply_data.html#secImageBindingUpdates", null ],
        [ "Binding images to output attachments", "page_supply_data.html#secImageBindingOutAttachments", null ],
        [ "Swapchains, surfaces and displays", "page_supply_data.html#secImageDisplays", null ],
        [ "Binding images to input attachments", "page_supply_data.html#secImageBindingInAttachments", null ]
      ] ],
      [ "Other data", "page_supply_data.html#secOtherData", [
        [ "Push constants", "page_supply_data.html#secPushConstants", null ],
        [ "Indirect drawing buffers", "page_supply_data.html#secIndirectBuffers", null ],
        [ "Queries", "page_supply_data.html#secQueries", null ],
        [ "Timestamps", "page_supply_data.html#secTimestamps", null ]
      ] ]
    ] ],
    [ "How to perform GPU-level computation", "page_computation.html", [
      [ "How to perform GPU-level computation", "page_computation.html#secComputation", [
        [ "Computation pipelines", "page_computation.html#subCompPipelines", null ],
        [ "Compute passes", "page_computation.html#subCompPasses", null ]
      ] ]
    ] ],
    [ "How to write shader and computation code", "page_code.html", [
      [ "How to write shader and computation code", "page_code.html#secCode", [
        [ "Opening directive", "page_code.html#subPreamble", null ],
        [ "Accessing binding points", "page_code.html#subAccessingVars", [
          [ "Accessing vertex and instance data buffers", "page_code.html#ssAccVertexBuffers", null ],
          [ "Accessing uniform buffers", "page_code.html#ssAccUniformBuffers", null ],
          [ "Accessing storage buffers", "page_code.html#ssAccStorageBuffers", null ],
          [ "Accessing texel buffers", "page_code.html#ssAccTexelBuffers", null ],
          [ "Accessing push constants", "page_code.html#ssAccPushCon", null ],
          [ "Accessing inter-shader variables", "page_code.html#ssAccInterShader", null ],
          [ "Accessing textures (sampled images)", "page_code.html#ssAccTextures", null ],
          [ "Accessing storage images", "page_code.html#ssAccStorageImg", null ],
          [ "Accessing input attachments", "page_code.html#ssAccInputAtt", null ],
          [ "Accessing samplers", "page_code.html#ssAccSamplers", null ],
          [ "Accessing output attachments", "page_code.html#ssAccOutputAtt", null ],
          [ "Accessing binding point arrays", "page_code.html#ssAccResourceArrays", null ]
        ] ],
        [ "Declaring and using local variables", "page_code.html#subDeclaringVars", [
          [ "Immutable variables", "page_code.html#ssImmutableVars", null ],
          [ "Mutable variables and arrays", "page_code.html#ssMutableVars", null ],
          [ "Shared variables", "page_code.html#ssSharedVars", null ],
          [ "Atomic variables", "page_code.html#ssAtomicVars", null ]
        ] ],
        [ "Accessing built-in variables", "page_code.html#subBuiltinVars", null ],
        [ "Indexing operators", "page_code.html#subIndexing", [
          [ "Local arrays", "page_code.html#ssIndLocalArr", null ],
          [ "Vectors", "page_code.html#ssIndVectors", null ],
          [ "Vector swizzles", "page_code.html#ssIndVecSwizzles", null ],
          [ "Matrices", "page_code.html#ssIndMatrices", null ],
          [ "Buffers containing single structure", "page_code.html#ssIndBuffersSingle", null ],
          [ "Buffers containing multiple structures", "page_code.html#ssIndBuffersMultiple", null ],
          [ "Buffers containing multiple simple objects", "page_code.html#ssIndBuffersSimple", null ],
          [ "Arrays of buffers", "page_code.html#ssIndBuffersArrays", null ],
          [ "Vertex and instance buffers", "page_code.html#ssIndBuffersVertex", null ],
          [ "Inter-shader variables of structural types", "page_code.html#ssIndInterShader", null ]
        ] ],
        [ "Basic control constructs", "page_code.html#subControlsConstructs", [
          [ "'If/Else/Fi' conditionals", "page_code.html#ssIf", null ],
          [ "'Select' conditionals", "page_code.html#ssSelect", null ],
          [ "'Do/While' loops", "page_code.html#ssDoWhile", null ],
          [ "'For' loops", "page_code.html#ssFor", null ],
          [ "'Switch' conditionals", "page_code.html#ssSwitch", null ],
          [ "Type conversions", "page_code.html#ssTypeConv", null ],
          [ "GPU-level functions", "page_code.html#ssFunctions", null ]
        ] ]
      ] ]
    ] ],
    [ "How to create reusable GPU functions", "page_reusable_fun.html", [
      [ "How to create reusable GPU functions", "page_reusable_fun.html#secReusableFun", [
        [ "Macro functions", "page_reusable_fun.html#subGpuFnMacro", null ],
        [ "Real GPU functions", "page_reusable_fun.html#subGpuFnReal", null ]
      ] ]
    ] ],
    [ "Debugging VPP programs", "page_debugging.html", [
      [ "Debugging VPP programs", "page_debugging.html#secDebugging", [
        [ "Debug probes", "page_debugging.html#secDebugProbes", null ],
        [ "Vulkan validation support", "page_debugging.html#secValidation", null ],
        [ "Shader compilation log", "page_debugging.html#secShaderLog", null ]
      ] ]
    ] ],
    [ "How to use VPP with GLM", "page_support_g_l_m.html", [
      [ "How to use VPP with GLM", "page_support_g_l_m.html#secUsageGLM", null ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"classvpp_1_1_float.html#a358d5cbc7ea1079777203379532ba915",
"classvpp_1_1_normalized_sampler.html#a0cbd2a2524e00136e9f6986951cd9a73",
"classvpp_1_1_surface.html#af60629371a52b38933aa7b3bce27234e",
"classvpp_1_1gvector.html#a48d10c84ccc9e1da2da7b22d9acf61a6",
"page_code.html#ssAccTextures",
"vpp_lang_constructs_8hpp_source.html",
"vpp_lang_functions_8hpp.html#a8649ca6aaaddaffc66b9b016b6c6d0d7"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> vpp-0.8.1.zip: html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "VPP", "index.html", [
    [ "System classes", "index.html#sysClasses", null ],
    [ "Render and compute pass construction classes", "index.html#renderPassConstruction", null ],
    [ "Resource objects", "index.html#resObjects", null ],
    [ "Memory allocation", "index.html#memAlloc", null ],
    [ "Data containers", "index.html#dataContainers", null ],
    [ "Pipeline construction classes", "index.html#pipelineConstruction", null ],
    [ "High level execution", "index.html#cmdExecHi", null ],
    [ "Recording and execution of commands", "index.html#cmdExecLo", null ],
    [ "Synchronization primitives", "index.html#syncPrimitives", null ],
    [ "Rendering configuration classes", "index.html#renderOptions", null ],
    [ "Resource binding points", "index.html#bindPoints", [
      [ "Vertex and instance data", "index.html#bpVertex", null ],
      [ "Uniform, storage and texel data buffers", "index.html#vpUniform", null ],
      [ "Push constants", "index.html#bpPushcon", null ],
      [ "Images and textures", "index.html#bpImg", null ],
      [ "Arrays of resource binding points", "index.html#bpArr", null ],
      [ "Render graph attachments", "index.html#bpAttach", null ],
      [ "Inter-shader communication", "index.html#bpIO", null ]
    ] ],
    [ "Binding point accessors", "index.html#bpAccessors", null ],
    [ "Resource views", "index.html#resViews", null ],
    [ "Resource binding helpers", "index.html#resBindHelpers", null ],
    [ "Shader binding points", "index.html#shBindPoints", null ],
    [ "Shader interface classes", "index.html#shInterfaces", null ],
    [ "Shader language simple data types", "index.html#shSimpleTypes", null ],
    [ "Shader language compound data types", "index.html#shCompoundTypes", null ],
    [ "Shader language special data types", "index.html#shSpecialTypes", null ],
    [ "Shader language constructs", "index.html#shLangConstructs", null ],
    [ "Shader language functions", "index.html#shLangFunctions", null ],
    [ "Shader language functions for accessing textures and images", "index.html#shLangImgFunctions", null ],
    [ "Debugging helpers", "index.html#dbgHelpers", null ],
    [ "Group computation algorithms", "index.html#shLangGroupAlgs", null ],
    [ "How to build and use VPP under Visual Studio", "page_build_v_s.html", [
      [ "How to build and use VPP under Visual Studio", "page_build_v_s.html#secBuildVS", [
        [ "Build properties", "page_build_v_s.html#secBuildProps", null ],
        [ "Configurations and platforms", "page_build_v_s.html#secConfigs", null ],
        [ "Project file", "page_build_v_s.html#secProject", null ]
      ] ]
    ] ],
    [ "General overview of rendering with VPP", "page_general_overview.html", null ],
    [ "How do C++ shaders work", "page_shaders_explanation.html", null ],
    [ "How do render graphs work", "page_render_graphs.html", [
      [ "How do render graphs work", "page_render_graphs.html#secHowDoRenderGraphs", [
        [ "Render graph basics", "page_render_graphs.html#secRenderGraphBasics", null ],
        [ "Render pass basics", "page_render_graphs.html#secRenderPassBasics", null ],
        [ "Advanced topics", "page_render_graphs.html#secAdvanced", null ]
      ] ]
    ] ],
    [ "How do pipelines work", "page_pipelines.html", [
      [ "How do pipelines work", "page_pipelines.html#secHowDoPipelines", [
        [ "Defining custom pipelines - pipeline configurations", "page_pipelines.html#secPipelineConfigs", null ],
        [ "Compiled form - pipeline layouts", "page_pipelines.html#secPipelineLayouts", null ],
        [ "Fully realized form - pipelines", "page_pipelines.html#secPipelines", null ]
      ] ]
    ] ],
    [ "Methods of supplying data", "page_supply_data.html", [
      [ "Buffers", "page_supply_data.html#secBuffers", [
        [ "Basic buffer classes in VPP", "page_supply_data.html#secBufferClasses", null ],
        [ "Buffer types and usages", "page_supply_data.html#secBufferUsages", null ],
        [ "Memory allocation", "page_supply_data.html#secBufferMemory", null ],
        [ "Vectors", "page_supply_data.html#secBufferVectors", null ],
        [ "Buffer views", "page_supply_data.html#secBufferViews", null ],
        [ "Buffer binding points", "page_supply_data.html#secBufferBindingPoints", null ],
        [ "Shader data blocks", "page_supply_data.html#secShaderDataBlocks", null ],
        [ "Binding buffers to points", "page_supply_data.html#secBufferBindingUpdates", null ],
        [ "Binding vertex buffers to pipelines", "page_supply_data.html#secBufferBindingVertex", null ],
        [ "Defining the structure for vertex buffers", "page_supply_data.html#secBufferDefiningVertex", null ],
        [ "Defining the structure for instance buffers", "page_supply_data.html#secBufferDefiningInstance", null ],
        [ "Defining the structure for uniform buffers", "page_supply_data.html#secBufferDefiningUniform", null ]
      ] ],
      [ "Images", "page_supply_data.html#secImages", [
        [ "Basic image classes in VPP", "page_supply_data.html#secImageClasses", null ],
        [ "Images with dynamic format", "page_supply_data.html#secImageDynFormat", null ],
        [ "Image types and usages", "page_supply_data.html#secImageUsages", null ],
        [ "Memory allocation", "page_supply_data.html#secImageMemory", null ],
        [ "Samplers", "page_supply_data.html#secImageSamplers", null ],
        [ "Image views", "page_supply_data.html#secImageViews", null ],
        [ "Image binding points", "page_supply_data.html#secImageBindingPoints", null ],
        [ "Binding images to points", "page_supply_data.html#secImageBindingUpdates", null ],
        [ "Binding images to output attachments", "page_supply_data.html#secImageBindingOutAttachments", null ],
        [ "Swapchains, surfaces and displays", "page_supply_data.html#secImageDisplays", null ],
        [ "Binding images to input attachments", "page_supply_data.html#secImageBindingInAttachments", null ]
      ] ],
      [ "Other data", "page_supply_data.html#secOtherData", [
        [ "Push constants", "page_supply_data.html#secPushConstants", null ],
        [ "Indirect drawing buffers", "page_supply_data.html#secIndirectBuffers", null ],
        [ "Queries", "page_supply_data.html#secQueries", null ],
        [ "Timestamps", "page_supply_data.html#secTimestamps", null ]
      ] ]
    ] ],
    [ "How to perform GPU-level computation", "page_computation.html", [
      [ "How to perform GPU-level computation", "page_computation.html#secComputation", [
        [ "Computation pipelines", "page_computation.html#subCompPipelines", null ],
        [ "Compute passes", "page_computation.html#subCompPasses", null ]
      ] ]
    ] ],
    [ "How to write shader and computation code", "page_code.html", [
      [ "How to write shader and computation code", "page_code.html#secCode", [
        [ "Opening directive", "page_code.html#subPreamble", null ],
        [ "Accessing binding points", "page_code.html#subAccessingVars", [
          [ "Accessing vertex and instance data buffers", "page_code.html#ssAccVertexBuffers", null ],
          [ "Accessing uniform buffers", "page_code.html#ssAccUniformBuffers", null ],
          [ "Accessing storage buffers", "page_code.html#ssAccStorageBuffers", null ],
          [ "Accessing texel buffers", "page_code.html#ssAccTexelBuffers", null ],
          [ "Accessing push constants", "page_code.html#ssAccPushCon", null ],
          [ "Accessing inter-shader variables", "page_code.html#ssAccInterShader", null ],
          [ "Accessing textures (sampled images)", "page_code.html#ssAccTextures", null ],
          [ "Accessing storage images", "page_code.html#ssAccStorageImg", null ],
          [ "Accessing input attachments", "page_code.html#ssAccInputAtt", null ],
          [ "Accessing samplers", "page_code.html#ssAccSamplers", null ],
          [ "Accessing output attachments", "page_code.html#ssAccOutputAtt", null ],
          [ "Accessing binding point arrays", "page_code.html#ssAccResourceArrays", null ]
        ] ],
        [ "Declaring and using local variables", "page_code.html#subDeclaringVars", [
          [ "Immutable variables", "page_code.html#ssImmutableVars", null ],
          [ "Mutable variables and arrays", "page_code.html#ssMutableVars", null ],
          [ "Shared variables", "page_code.html#ssSharedVars", null ],
          [ "Atomic variables", "page_code.html#ssAtomicVars", null ]
        ] ],
        [ "Accessing built-in variables", "page_code.html#subBuiltinVars", null ],
        [ "Indexing operators", "page_code.html#subIndexing", [
          [ "Local arrays", "page_code.html#ssIndLocalArr", null ],
          [ "Vectors", "page_code.html#ssIndVectors", null ],
          [ "Vector swizzles", "page_code.html#ssIndVecSwizzles", null ],
          [ "Matrices", "page_code.html#ssIndMatrices", null ],
          [ "Buffers containing single structure", "page_code.html#ssIndBuffersSingle", null ],
          [ "Buffers containing multiple structures", "page_code.html#ssIndBuffersMultiple", null ],
          [ "Buffers containing multiple simple objects", "page_code.html#ssIndBuffersSimple", null ],
          [ "Arrays of buffers", "page_code.html#ssIndBuffersArrays", null ],
          [ "Vertex and instance buffers", "page_code.html#ssIndBuffersVertex", null ],
          [ "Inter-shader variables of structural types", "page_code.html#ssIndInterShader", null ]
        ] ],
        [ "Basic control constructs", "page_code.html#subControlsConstructs", [
          [ "'If/Else/Fi' conditionals", "page_code.html#ssIf", null ],
          [ "'Select' conditionals", "page_code.html#ssSelect", null ],
          [ "'Do/While' loops", "page_code.html#ssDoWhile", null ],
          [ "'For' loops", "page_code.html#ssFor", null ],
          [ "'Switch' conditionals", "page_code.html#ssSwitch", null ],
          [ "Type conversions", "page_code.html#ssTypeConv", null ],
          [ "GPU-level functions", "page_code.html#ssFunctions", null ]
        ] ]
      ] ]
    ] ],
    [ "How to create reusable GPU functions", "page_reusable_fun.html", [
      [ "How to create reusable GPU functions", "page_reusable_fun.html#secReusableFun", [
        [ "Macro functions", "page_reusable_fun.html#subGpuFnMacro", null ],
        [ "Real GPU functions", "page_reusable_fun.html#subGpuFnReal", null ]
      ] ]
    ] ],
    [ "Debugging VPP programs", "page_debugging.html", [
      [ "Debugging VPP programs", "page_debugging.html#secDebugging", [
        [ "Debug probes", "page_debugging.html#secDebugProbes", null ],
        [ "Vulkan validation support", "page_debugging.html#secValidation", null ],
        [ "Shader compilation log", "page_debugging.html#secShaderLog", null ]
      ] ]
    ] ],
    [ "How to use VPP with GLM", "page_support_g_l_m.html", [
      [ "How to use VPP with GLM", "page_support_g_l_m.html#secUsageGLM", null ]
    ] ],
    [ "Validation errors troubleshooting", "page_validation_errors.html", [
      [ "Validation errors troubleshooting", "page_validation_errors.html#secValidationErrors", null ]
    ] ],
    [ "Release notes", "page_release_notes.html", [
      [ "Release notes", "page_release_notes.html#secReleaseNotes", null ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"classvpp_1_1_display.html#a4bb499f0d2b464068325ae427bafb0da",
"classvpp_1_1_mappable_device_memory.html#a60f41eb26f0f0ea32dd81ddd9e439d86",
"classvpp_1_1_rendering_options.html#a93be2d23ad6d2b65720622af01c8cfa9",
"classvpp_1_1_vec4.html#af6d5370e65aeb20b653aa222341dcc1b",
"functions_g.html",
"structvpp_1_1_s_normalized_sampler.html#a07c9021009519f942d8f1e034cbcbc00",
"vpp_lang_functions_8hpp.html#a475a8e395fb389c55d2cf84045deaf97",
"vpp_lang_functions_8hpp.html#acf4436166073667157f9873f49e9bf9f"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
